==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/secretsmanager/kotlin/inputs/GetSecretPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.secretsmanager.kotlin.inputs

import com.pulumi.aws.secretsmanager.inputs.GetSecretPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * A collection of arguments for invoking getSecret.
 * @property arn ARN of the secret to retrieve.
 * @property name Name of the secret to retrieve.
 */
public data class GetSecretPlainArgs(
    public val arn: String? = null,
    public val name: String? = null,
) : ConvertibleToJava<com.pulumi.aws.secretsmanager.inputs.GetSecretPlainArgs> {
    override fun toJava(): com.pulumi.aws.secretsmanager.inputs.GetSecretPlainArgs =
        com.pulumi.aws.secretsmanager.inputs.GetSecretPlainArgs.builder()
            .arn(arn?.let({ args0 -> args0 }))
            .name(name?.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetSecretPlainArgs].
 */
@PulumiTagMarker
public class GetSecretPlainArgsBuilder internal constructor() {
    private var arn: String? = null

    private var name: String? = null

    /**
     * @param value ARN of the secret to retrieve.
     */
    @JvmName("ysfnddroelsosppk")
    public suspend fun arn(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.arn = mapped
    }

    /**
     * @param value Name of the secret to retrieve.
     */
    @JvmName("aqjdjevlvupmrenh")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.name = mapped
    }

    internal fun build(): GetSecretPlainArgs = GetSecretPlainArgs(
        arn = arn,
        name = name,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/secretsmanager/kotlin/inputs/GetSecretPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.secretsmanager.kotlin.inputs

import com.pulumi.aws.secretsmanager.inputs.GetSecretPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * A collection of arguments for invoking getSecret.
 * @property arn ARN of the secret to retrieve.
 * @property name Name of the secret to retrieve.
 * @property tags Tags of the secret.
 */
public data class GetSecretPlainArgs(
    public val arn: String? = null,
    public val name: String? = null,
    public val tags: Map<String, String>? = null,
) : ConvertibleToJava<com.pulumi.aws.secretsmanager.inputs.GetSecretPlainArgs> {
    override fun toJava(): com.pulumi.aws.secretsmanager.inputs.GetSecretPlainArgs =
        com.pulumi.aws.secretsmanager.inputs.GetSecretPlainArgs.builder()
            .arn(arn?.let({ args0 -> args0 }))
            .name(name?.let({ args0 -> args0 }))
            .tags(tags?.let({ args0 -> args0.map({ args0 -> args0.key.to(args0.value) }).toMap() })).build()
}

/**
 * Builder for [GetSecretPlainArgs].
 */
@PulumiTagMarker
public class GetSecretPlainArgsBuilder internal constructor() {
    private var arn: String? = null

    private var name: String? = null

    private var tags: Map<String, String>? = null

    /**
     * @param value ARN of the secret to retrieve.
     */
    @JvmName("mwyklpjubttouove")
    public suspend fun arn(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.arn = mapped
    }

    /**
     * @param value Name of the secret to retrieve.
     */
    @JvmName("qajidcwbgxpfxcef")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value Tags of the secret.
     */
    @JvmName("kqukpdkisluulsqn")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.tags = mapped
    }

    /**
     * @param values Tags of the secret.
     */
    @JvmName("lwroxpamoeogpvyr")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.tags = mapped
    }

    internal fun build(): GetSecretPlainArgs = GetSecretPlainArgs(
        arn = arn,
        name = name,
        tags = tags,
    )
}
